@@ -5,7 +5,10 @@ use crate::object::*;
 use crate::pyport::Py_ssize_t;
 
 #[cfg(Py_3_8)]
-pub enum _PyOpcache {}
+#[repr(C)]
+pub struct _PyOpcache {
+    _private: [u8; 0],
+}
 
 #[repr(C)]
 #[derive(Copy)]
