@@ -1,5 +1,6 @@
 use libc::{c_char, c_int, c_long, c_uchar};
-use object::PyObject;
+
+use crate::object::PyObject;
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
@@ -61,12 +62,11 @@ extern "C" {
     pub fn PyImport_GetImporter(path: *mut PyObject) -> *mut PyObject;
     pub fn PyImport_Import(name: *mut PyObject) -> *mut PyObject;
     pub fn PyImport_ReloadModule(m: *mut PyObject) -> *mut PyObject;
+    #[cfg(not(Py_3_9))]
     pub fn PyImport_Cleanup() -> ();
     pub fn PyImport_ImportFrozenModuleObject(name: *mut PyObject) -> c_int;
     pub fn PyImport_ImportFrozenModule(name: *const c_char) -> c_int;
 
-    // pub static mut PyNullImporter_Type: PyTypeObject; -- does not actually exist in shared library
-
     pub fn PyImport_AppendInittab(
         name: *const c_char,
         initfunc: Option<unsafe extern "C" fn() -> *mut PyObject>,
@@ -97,4 +97,44 @@ extern "C" {
     pub static mut PyImport_Inittab: *mut _inittab;
 
     pub fn PyImport_ExtendInittab(newtab: *const _inittab) -> c_int;
+
+    #[cfg(not(Py_3_7))]
+    pub fn _PyImport_FindBuiltin(name: *const c_char) -> *mut PyObject;
+    #[cfg(all(Py_3_7, not(Py_3_9)))]
+    pub fn _PyImport_FindBuiltin(name: *const c_char, modules: *mut PyObject) -> *mut PyObject;
+
+    pub fn _PyImport_FindExtensionObject(
+        name: *mut PyObject,
+        filename: *mut PyObject,
+    ) -> *mut PyObject;
+
+    #[cfg(all(Py_3_7, not(Py_3_9)))]
+    pub fn _PyImport_FindExtensionObjectEx(
+        name: *mut PyObject,
+        filename: *mut PyObject,
+        modules: *mut PyObject,
+    ) -> *mut PyObject;
+
+    #[cfg(not(Py_3_7))]
+    pub fn _PyImport_FixupBuiltin(module: *mut PyObject, name: *const c_char) -> c_int;
+    #[cfg(Py_3_7)]
+    pub fn _PyImport_FixupBuiltin(
+        module: *mut PyObject,
+        name: *const c_char,
+        modules: *mut PyObject,
+    ) -> c_int;
+
+    #[cfg(not(Py_3_7))]
+    pub fn _PyImport_FixupExtensionObject(
+        module: *mut PyObject,
+        name: *mut PyObject,
+        filename: *mut PyObject,
+    ) -> c_int;
+    #[cfg(Py_3_7)]
+    pub fn _PyImport_FixupExtensionObject(
+        module: *mut PyObject,
+        name: *mut PyObject,
+        filename: *mut PyObject,
+        modules: *mut PyObject,
+    ) -> c_int;
 }
