@@ -1,5 +1,14 @@
 #![no_std]
-#![allow(non_camel_case_types, non_snake_case, non_upper_case_globals, unused_parens)]
+#![allow(
+    non_camel_case_types,
+    non_snake_case,
+    non_upper_case_globals,
+    unused_parens,
+    clippy::missing_safety_doc,
+    clippy::transmute_ptr_to_ptr,
+    clippy::unused_unit,
+    clippy::identity_op
+)]
 #![cfg_attr(Py_LIMITED_API, allow(unused_imports))]
 
 // old: marked with TODO
@@ -9,6 +18,11 @@
 // new:
 // Based on the headers of Python 3.3.0, 3.4.0 and 3.5.0.
 
+// Macro for marking parts of the Python headers as ignored.
+macro_rules! ignore {
+    ( $( $_tokens:tt )* ) => {};
+}
+
 pub use crate::bltinmodule::*;
 pub use crate::boolobject::*;
 pub use crate::bytearrayobject::*;
