@@ -201,7 +201,10 @@ pub type vectorcallfunc = unsafe extern "C" fn(
 ) -> *mut crate::object::PyObject;
 
 #[cfg(Py_LIMITED_API)]
-pub enum PyTypeObject {}
+#[repr(C)]
+pub struct PyTypeObject {
+    _private: [u8; 0],
+}
 
 #[cfg(not(Py_LIMITED_API))]
 mod typeobject {
@@ -723,9 +726,12 @@ extern "C" {
     #[cfg(Py_3_4)]
     pub fn PyType_GetSlot(arg1: *mut PyTypeObject, arg2: c_int) -> *mut c_void;
 
-
     #[cfg(Py_3_9)]
-    pub fn PyType_FromModuleAndSpec(arg1: *mut PyObject, arg2: *mut PyType_Spec, arg3: *mut PyObject) -> *mut PyObject;
+    pub fn PyType_FromModuleAndSpec(
+        arg1: *mut PyObject,
+        arg2: *mut PyType_Spec,
+        arg3: *mut PyObject,
+    ) -> *mut PyObject;
 
     #[cfg(Py_3_9)]
     pub fn PyType_GetModule(arg1: *mut PyTypeObject) -> *mut PyObject;
