@@ -1,7 +1,8 @@
 use core::ptr;
 use libc::{c_char, c_int, c_void};
-use object::*;
-use pyport::Py_ssize_t;
+
+use crate::object::*;
+use crate::pyport::Py_ssize_t;
 
 #[inline]
 pub unsafe fn PyObject_DelAttrString(o: *mut PyObject, attr_name: *const c_char) -> c_int {
@@ -15,6 +16,9 @@ pub unsafe fn PyObject_DelAttr(o: *mut PyObject, attr_name: *mut PyObject) -> c_
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
+    #[cfg(Py_3_9)]
+    pub fn PyObject_CallNoArgs(func: *mut PyObject) -> *mut PyObject;
+
     pub fn PyObject_Call(
         callable: *mut PyObject,
         args: *mut PyObject,
@@ -79,7 +83,7 @@ extern "C" {
     ) -> c_int;
 }
 
-#[cfg(not(Py_LIMITED_API))]
+#[cfg(all(not(Py_LIMITED_API), not(Py_3_9)))]
 #[inline]
 pub unsafe fn PyObject_CheckBuffer(o: *mut PyObject) -> c_int {
     let tp_as_buffer = (*(*o).ob_type).tp_as_buffer;
@@ -90,6 +94,8 @@ pub unsafe fn PyObject_CheckBuffer(o: *mut PyObject) -> c_int {
 #[cfg(not(Py_LIMITED_API))]
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
+    #[cfg(Py_3_9)]
+    pub fn PyObject_CheckBuffer(o: *mut PyObject) -> c_int;
     pub fn PyObject_GetBuffer(obj: *mut PyObject, view: *mut Py_buffer, flags: c_int) -> c_int;
     pub fn PyBuffer_GetPointer(view: *mut Py_buffer, indices: *mut Py_ssize_t) -> *mut c_void;
     pub fn PyBuffer_ToContiguous(
@@ -135,7 +141,8 @@ extern "C" {
 pub unsafe fn PyIter_Check(o: *mut PyObject) -> c_int {
     (match (*(*o).ob_type).tp_iternext {
         Some(tp_iternext) => {
-            tp_iternext as *const c_void != ::object::_PyObject_NextNotImplemented as *const c_void
+            tp_iternext as *const c_void
+                != crate::object::_PyObject_NextNotImplemented as *const c_void
         }
         None => false,
     }) as c_int
@@ -171,7 +178,8 @@ extern "C" {
     pub fn PyNumber_Or(o1: *mut PyObject, o2: *mut PyObject) -> *mut PyObject;
 }
 
-#[cfg(not(Py_LIMITED_API))]
+// Note: Py 3.8 has PyIndex_Check as a function, prior to that it was only availabe as a macro
+#[cfg(all(not(Py_LIMITED_API), not(Py_3_8)))]
 #[inline]
 pub unsafe fn PyIndex_Check(o: *mut PyObject) -> c_int {
     let tp_as_number = (*(*o).ob_type).tp_as_number;
@@ -180,8 +188,7 @@ pub unsafe fn PyIndex_Check(o: *mut PyObject) -> c_int {
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
-    // Note: without Py_LIMITED_API, PyIndex_Check is a macro instead
-    #[cfg(all(Py_3_8, Py_LIMITED_API))]
+    #[cfg(Py_3_8)]
     pub fn PyIndex_Check(o: *mut PyObject) -> c_int;
 
     pub fn PyNumber_Index(o: *mut PyObject) -> *mut PyObject;
